summaryrefslogtreecommitdiffstats
path: root/chrome/browser/find_backend_unittest.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/find_backend_unittest.cc
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/find_backend_unittest.cc')
-rw-r--r--chrome/browser/find_backend_unittest.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/find_backend_unittest.cc b/chrome/browser/find_backend_unittest.cc
index 260e897..3b2cdcc 100644
--- a/chrome/browser/find_backend_unittest.cc
+++ b/chrome/browser/find_backend_unittest.cc
@@ -7,15 +7,15 @@
typedef RenderViewHostTestHarness FindBackendTest;
// This test takes two WebContents objects, searches in both of them and
// tests the internal state for find_text and find_prepopulate_text.
TEST_F(FindBackendTest, InternalState) {
// Initial state for the WebContents is blank strings.
EXPECT_EQ(string16(), contents()->find_prepopulate_text());
EXPECT_EQ(string16(), contents()->find_text());
- // Get another WebContents object ready.
- TestWebContents contents2(profile_.get(), NULL);
+ // Get another TabContents object ready.
+ TestTabContents contents2(profile_.get(), NULL);
// No search has still been issued, strings should be blank.
EXPECT_EQ(string16(), contents()->find_prepopulate_text());
@@ -27,7 +27,7 @@ TEST_F(FindBackendTest, InternalState) {
string16 search_term2 = L" but the economy ";
string16 search_term3 = L" eated it. ";
// Start searching in the first WebContents.
contents()->StartFinding(search_term1, true); // true=forward.
// Pre-populate string should always match between the two, but find_text
@@ -37,7 +37,7 @@ TEST_F(FindBackendTest, InternalState) {
EXPECT_EQ(search_term1, contents2.find_prepopulate_text());
EXPECT_EQ(string16(), contents2.find_text());
// Now search in the other WebContents.
contents2.StartFinding(search_term2, true); // true=forward.
// Again, pre-populate string should always match between the two, but
@@ -47,7 +47,7 @@ TEST_F(FindBackendTest, InternalState) {
EXPECT_EQ(search_term2, contents2.find_prepopulate_text());
EXPECT_EQ(search_term2, contents2.find_text());
// Search again in the first WebContents.
contents()->StartFinding(search_term3, true); // true=forward.
// Once more, pre-populate string should always match between the two, but
@@ -7,15 +7,15 @@
typedef RenderViewHostTestHarness FindBackendTest;
-// This test takes two WebContents objects, searches in both of them and
+// This test takes two TabContents objects, searches in both of them and
// tests the internal state for find_text and find_prepopulate_text.
TEST_F(FindBackendTest, InternalState) {
@@ -7,15 +7,15 @@
// tests the internal state for find_text and find_prepopulate_text.
TEST_F(FindBackendTest, InternalState) {
- // Initial state for the WebContents is blank strings.
+ // Initial state for the TabContents is blank strings.
EXPECT_EQ(string16(), contents()->find_prepopulate_text());
EXPECT_EQ(string16(), contents()->find_text());
@@ -27,7 +27,7 @@ TEST_F(FindBackendTest, InternalState) {
string16 search_term2 = L" but the economy ";
string16 search_term3 = L" eated it. ";
- // Start searching in the first WebContents.
+ // Start searching in the first TabContents.
contents()->StartFinding(search_term1, true); // true=forward.
// Pre-populate string should always match between the two, but find_text
@@ -37,7 +37,7 @@ TEST_F(FindBackendTest, InternalState) {
EXPECT_EQ(search_term1, contents2.find_prepopulate_text());
EXPECT_EQ(string16(), contents2.find_text());
- // Now search in the other WebContents.
+ // Now search in the other TabContents.
contents2.StartFinding(search_term2, true); // true=forward.
// Again, pre-populate string should always match between the two, but
@@ -47,7 +47,7 @@ TEST_F(FindBackendTest, InternalState) {
EXPECT_EQ(search_term2, contents2.find_prepopulate_text());
EXPECT_EQ(search_term2, contents2.find_text());
- // Search again in the first WebContents.
+ // Search again in the first TabContents.
contents()->StartFinding(search_term3, true); // true=forward.
// Once more, pre-populate string should always match between the two, but